{ lib, pkgs, ... }:

{
  boot.kernelPackages = lib.mkOverride 2000 pkgs.linuxPackages_latest;
  boot.kernelParams = [ "quiet" ];

  services.openssh.enable = true;
  security.sudo.wheelNeedsPassword = false;

  nix.gc.automatic = lib.mkDefault true;
  nix.gc.options = lib.mkDefault "--delete-older-than 1d";
  nix.trustedUsers = [ "root" "@wheel" ];

  environment.variables = {
    EDITOR = "vim"; # fight me :-)

    # automatically runs `nix-env -iA nixos.$package` when
    # someone tries to run something that is not installed
    NIX_AUTO_INSTALL = "1";
  };

  environment.systemPackages = with pkgs; [
    alacritty.terminfo
    kitty.terminfo
    rxvt_unicode.terminfo
    termite.terminfo
    bat
    bottom
    exa
    fd
    git
    htop
    nload
    ripgrep
    rsync
    tcpdump
    tmux
    vim
    wget
    jq
  ];

  programs.bash.shellAliases = {
    ".." = "cd ..";
    use = "nix-shell -p";
    cat = "bat --style=header";
    grep = "rg";
    ls = "exa";
    ll = "exa -l";
    la = "exa -la";
    tree = "exa -T";
    apt = "echo 'please use nix-env -iA nixos.<packagename> instead to install packages.'";
  };

  users.mutableUsers = false;
  users.users.c3h = {
    isNormalUser = true;
    password = "c3h";
    extraGroups = [ "wheel" ];
  };
}
